<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bs" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Zatvori (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Sažmi</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Proširi</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Odbaci upozorenje</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln riječ</numerusform>
            <numerusform>%Ln riječi</numerusform>
            <numerusform>%Ln riječi</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuta</numerusform>
            <numerusform>%Ln minute</numerusform>
            <numerusform>%Ln minuta</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% od %Ln minute</numerusform>
            <numerusform>%L1% od %Ln minute</numerusform>
            <numerusform>%L1% od %Ln minuta</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% od %Ln riječi</numerusform>
            <numerusform>%L1% od %Ln riječi</numerusform>
            <numerusform>%L1% od %Ln riječi</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Dnevno napredovanje</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Najduži niz</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Trenutni niz</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nema</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dan</numerusform>
            <numerusform>%n dana</numerusform>
            <numerusform>%n dana</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 – %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% od dnevnog cilja</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Odredi jezik</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez naziva %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (samo za čitanje)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Nažalost</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Nije moguće pohraniti &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Pohrani datoteku kao</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Nije moguće prebrisati &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Preimenuj datoteku</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Nije moguće preimenovati &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Ponovo učitati datoteku?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Ponovo učitati datoteku &apos;%1&apos; sa diska?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Sve nepohranjene izmjene bit će izgubljene.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ponovo učitaj</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Bez naziva %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Pohranjivanje u običnom tekstualnom formatu poništit će sva oblikovanja teksta. Poništiti oblikovanja?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Datoteka je izmijenjena</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Datoteka &apos;%1&apos; izmijenjena je u drugom programu.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Želite li ponovo učitati datoteku?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Ponovo učitaj</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Zanemari</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Datoteka je obrisana</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Datoteku %1 obrisao je drugi program.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Želite li pohraniti ili zatvoriti datoteku?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nije moguće otvoriti arhivu.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Potraži:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Zamijeni sa:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ne razlikuj velika od malih slova</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Samo cijele riječi</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Regularni izrazi (regexp)</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Traži iznad</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Traži ispod</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Pronađi</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Zamijeni</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Zamijeni sve</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Pronađi</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Zamijeni</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Zamijeniti %n rezultat?</numerusform>
            <numerusform>Zamijeniti %n rezultata?</numerusform>
            <numerusform>Zamijeniti %n rezultata?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Nažalost</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Izraz nije pronađen.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>OpenDocument Text</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Plain Text</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Sve datoteke</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Sve podržane datoteke</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Provjeri pravopis ...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nema prijedloga)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Otvori sliku</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Slike</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Odaberite jezik aplikacije:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Bilješka</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Molimo ponovo pokrenite aplikaciju da bi promjena jezika stupila na snagu.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nije moguće otvoriti arhivu.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Podešavanja</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Opća</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Traka s alatkama</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Provjera pravopisa</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Odaberite rječnik</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Nažalost</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Nije moguće otvoriti arhivu.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Arhiva ne sadržava odgovarajući rječnik.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Kratice</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Kratice se preklapaju. Želite li nastaviti?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Rječnik &quot;%1&quot; već postoji. Želite li ga zamijeniti?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Dnevni cilj</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ništa</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minuta:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Riječi:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Rad s tekstom</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Kursor uvijek vertikalno centriran</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Četvrtasti kursor</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Bolji prikaz slova</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Zvuk pisaće mašine</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Navodni znaci:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Navodnici</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Polunavodnici</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Scene</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Odvajanje scena pomoću:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Pohranjivanje</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Zapamti poziciju kursora</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Broj riječi</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Broj stranica</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Broj pasusa</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Broj znakova</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Znakova:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Pasusa:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Način utvrđivanja broja riječi</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Vratiti današnje dnevno napredovanje na nulu?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Piši Byte Order Mark u običnim tekstualnim datotekama</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Podrazumijevani format:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Poništi današnje dnevno napredovanje</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Raniji nizovi</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Zabilježi nizove</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Prikaži nizove</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Minimum za računanje napredovanja u nizu:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Utvrdi granice riječi</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Podijeli broj znakova sa šest</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Svako slovo računaj kao riječ</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Način utvrđivanja broja stranica</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Izgled</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Samo sličice</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Samo tekst</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Tekst pored sličica</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Tekst ispod sličica</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Pozicija teksta:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Elementi</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Pomjeri gore</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Pomjeri dolje</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Dodaj razdjelnicu</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Komanda</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Kratica</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Aktivnost</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Provjeri pravopis tokom kucanja</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Zaobiđi riječi pisane VELIKIM SLOVIMA</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Zaobiđi riječi koje sadržavaju brojeve</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jezik</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Vlastiti rječnik</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Ukloniti trenutno korišteni rječnik?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Elementi prozora</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Uvijek prikaži letvicu za pomjeranje teksta</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Uvijek prikaži meni i traku s alatkama</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Uvijek prikaži popis otvorenih datoteka i statistiku</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Nije validna RTF datoteka.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Neočekivani kraj datoteke.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Premjesti scene naprijed</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Prikaži popis scena</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Prikaži popis scena (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Sakrij popis scena (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Premjesti scene nazad</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Promjeni veličinu popisa scena</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Početna</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Uredi sesije</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>Sesije</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Preimenuj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Obriši</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Pređi na</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova sesija</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplikat sesije</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Preimenuj sesiju</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Obrisati označenu sesiju?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Naziv sesije:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Nažalost</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Naziv sesije već postoji.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>Nova ...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>Uredi ...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Počisti</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Vrati na predefinisanu</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Kratica:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Zamjena navodnika ...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Molimo sačekajte</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Provjeri pravopis</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>Zanemari</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Zanemari sve</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>Promijeni</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Promijeni sve</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Nema u rječniku:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Promijeni u:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Provjera pravopisa ...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Prekini</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Molimo sačekajte</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Nastaviti provjeru od početka teksta?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Provjera pravopisa završena.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Specijalni znaci</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Nedavno korišteni znaci</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Svi znaci</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalji</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Naziv:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Umetni</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Skupine</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Pisma</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Bez naziva %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Naziv:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Bez slike</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>S ponavljanjem</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrirana</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Razvučena</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Prilagođena</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Uvećana</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Providnost:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Pozicija:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Zaobljeni uglovi pozadine teksta</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Radijus:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Mutna pozadina teksta</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Sjenka pozadine teksta</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Vertikalno:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margine</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Prozor:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Stranica:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Uvučena prva linija teksta</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Iznad:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Ispod:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ukloni</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Izmijeni temu</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Pozadina prozora</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Boja:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Slika:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> px</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Pozadina teksta</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Pogrešno napisano:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Prored</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Jednostruki</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 redova</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dvostruki</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcionalni</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Razmak:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Pasus</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Uvlačak:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nova tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Teme</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Osnovne</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Gentle Blues</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Old School</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Space Dreams</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Writing Desk</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikat</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Prerađene</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Izmijeni</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Obriši</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Unesi</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Iznesi</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Obrisati temu &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Teme (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Unesi temu</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Iznesi temu</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Bitter Skies</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Enchantment</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Spy Games</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquility</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; – %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Obrisati podsjetnik?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Riječi:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Stranica:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pasusa:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Znakova:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Za koliko vremena</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>U koliko sati</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Za:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>U:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Vrijeme je isteklo!</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Vrsta:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Opis:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Izmijeni</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Obriši</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Podsjetnik nije pokrenut</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Podsjetnici</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novi</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Korišteni</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Poništiti izmjene podsjetnika?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 – %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Učitavanje tema</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Učitavanje zvuka</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Bez naziva</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otvori datoteku</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>O FocusWriteru</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Aplikacija za rad s tekstom na punom ekranu</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>&amp;copy; 2008&amp;ndash;%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Objavljeno pod &lt;a href=%1&gt;GPL 3&lt;/a&gt; licencom</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Koristi sličice &lt;a href=%1&gt;Oxygen&lt;/a&gt; teme</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>prema uslovima &lt;a href=%1&gt;LGPL 3&lt;/a&gt; licence</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Znakova: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Stranica: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Pasusa: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Riječi: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otvaranje %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Bez naziva %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Prikaži sve dokumente</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Pređi na sljedeći dokument</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Pređi na prethodni dokument</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Pređi na prvi dokument</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Pređi na posljednji dokument</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Pređi na dokument %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Učitavanje podešavanja</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Onemogućeno je pohranjivanje u rezervnu memoriju.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter nije zatvoren na regularan način.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Restaurirati iz rezervne memorije?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Neke od datoteka nije bilo moguće otvoriti.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Neke od datoteka otvorene su samo za čitanje.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; je noviji od rezervne kopije.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Prebrisati noviju datoteku?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Pohraniti izmjene?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Pohraniti izmjene u datoteci &apos;%1&apos; prije zatvaranja?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Sve izmjene bit će bespovratno izgubljene ukoliko ih ne pohranite.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Nije moguće učitati zvuk pisaće mašine.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>Otvori ...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Ponovo učitaj</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Pohrani</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Pohrani kao ...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>Preimenuj ...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Pohrani sve</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Uredi sesije</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova sesija</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Štampaj ...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Zatvori</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Izađi</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>Izmjena</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Opozovi</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Ponovi</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Isijeci</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Kopiraj</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Zalijepi</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Zalijepi neformatirano</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Označi sve</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Označi scenu</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Oblikovanje</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>Podebljano</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>Kurziv</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>Podvučeno</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Precrtano</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Eksponent</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Poravnaj slijeva</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Poravnaj po sredini</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Poravnaj zdesna</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Poravnaj obostrano</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Pomjeri ulijevo</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Pomjeri udesno</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Piši slijeva udesno</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Piši zdesna ulijevo</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Alatke</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Pretraga ...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Pronađi sljedeće</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Pronađi prethodno</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Zamjena ...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Navodnici</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Ispravi u cijelom dokumentu</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Ispravi u označenom tekstu</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Pravopis ...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Odredi jezik ...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>Podsjetnici ...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Specijalni znaci ...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Dnevno napredovanje</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Podešavanja</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Prikaži traku s alatkama</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Prikaži sličice u menijima</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Fokus na tekst</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Puni ekran</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>Minimiziraj</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>Teme ...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Podešavanja ...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Fokus poništen</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Fokus na jedan red teksta</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Fokus na tri reda teksta</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>Pasus</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Fokus na pasus</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Jezik aplikacije ...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Neke od datoteka nisu u podržanim formatima i ne mogu se otvoriti.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>Bez fokusa</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Jedan red teksta</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>Tri reda teksta</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O aplikaciji</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>O Qt-u</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Podešavanje stranice ...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Naslov</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Naslov &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Naslov &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Naslov &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Naslov &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Naslov &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Naslov &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>Obični tekst</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Ispravi navodnike u cijelom dokumentu</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Ispravi navodnike u označenom tekstu</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Datoteke koje će se otvoriti u trenutnoj sesiji.</translation>
    </message>
</context>
</TS>
